==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/FragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FragmentBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class FragmentBaseDescriptionMetadata extends Base {
        static b(a) {
            if (FragmentBaseDescriptionMetadata.a == null) {
                FragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FragmentBaseDescriptionMetadata.c(FragmentBaseDescriptionMetadata.a);
            }
            if (a.k(FragmentBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(FragmentBaseDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            FragmentBaseDescriptionMetadata.b(a);
            a.ac("FragmentBase", FragmentBaseDescriptionMetadata.a);
        }
    }
    FragmentBaseDescriptionMetadata.$t = markType(FragmentBaseDescriptionMetadata, 'FragmentBaseDescriptionMetadata');
    FragmentBaseDescriptionMetadata.a = null;
    return FragmentBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/FragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FragmentBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class FragmentBaseDescriptionMetadata extends Base {
        static b(a) {
            if (FragmentBaseDescriptionMetadata.a == null) {
                FragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FragmentBaseDescriptionMetadata.c(FragmentBaseDescriptionMetadata.a);
            }
            if (a.k(FragmentBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(FragmentBaseDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            FragmentBaseDescriptionMetadata.b(a);
            a.ad("FragmentBase", FragmentBaseDescriptionMetadata.a);
        }
    }
    FragmentBaseDescriptionMetadata.$t = markType(FragmentBaseDescriptionMetadata, 'FragmentBaseDescriptionMetadata');
    FragmentBaseDescriptionMetadata.a = null;
    return FragmentBaseDescriptionMetadata;
})();
